@@ -1,4 +1,4 @@
-#' Calculate signal-to-noise-ratio.
+#' Calculate signal-to-noise-ratio (SNR).
 #' 
 #' The function calculates the signal-to-noise ratio of an input signal 
 #' vector as the ratio between mean and max.
@@ -6,8 +6,19 @@
 #' @param data \code{eseis} object, \code{numeric} vector or list of 
 #' objects, data set to be processed.
 #' 
+#' @param scale \code{Character} value, scale of the output. One out of 
+#' \code{"lin"} (linear) and \code{"dB"} (decibel). Default is \code{"lin"}.
+#' 
 #' @param detrend \code{Logical} value, optionally detrend data set before
-#' calcualting snr.
+#' calculating snr. Default is \code{FALSE}
+#' 
+#' @param envelope \code{Logical} value, optionally calculate the signal 
+#' envelope before calculating the SNR. Default is \code{FALSE}.
+#' 
+#' @param method \code{Character} value, method used to calculate the SNR. 
+#' Available methods are \code{"max-mean"} (Ratio of maximum and mean signal),
+#' \code{"mean-sd"} (Ratio of mean and standard deviation). Default is 
+#' \code{max-mean}.
 #' 
 #' @return \code{Numeric} value, signal-to-noise ratio.
 #' 
@@ -18,18 +29,26 @@
 #' ## load example data set
 #' data(rockfall)
 #' 
-#' ## calculate snr with detrend option off and on
-#' snr <- signal_snr(data = rockfall_eseis)
+#' ## remove mean and calculate envelope beforehand
+#' x_prep <- signal_envelope(signal_detrend(rockfall_eseis))
+#' 
+#' ## calculate snr
+#' snr <- signal_snr(data = x_prep)
 #' print(snr$snr)
 #' 
-#' snr <- signal_snr(data = rockfall_eseis, 
-#'                   detrend = TRUE)
-#' print(snr$snr)
-#'                      
+#' ## calculate snr with preprocessing during function call, and in dB scale
+#' snr_dB <- signal_snr(data = rockfall_eseis, detrend = TRUE, 
+#'                      envelope = TRUE, scale = "dB")
+#' print(snr_dB$snr)
+#' 
 #' @export signal_snr
+
 signal_snr <- function(
   data,
-  detrend = FALSE
+  scale = "lin",
+  detrend = FALSE,
+  envelope = FALSE,
+  method = "max-mean"
 ) {
 
   ## check data structure
@@ -38,7 +57,10 @@ signal_snr <- function(
     ## apply function to list
     data_out <- lapply(X = data, 
                        FUN = eseis::signal_snr, 
-                       detrend = detrend)
+                       scale = scale,
+                       detrend = detrend,
+                       envelope = envelope,
+                       method = method)
     
     ## return output
     return(data_out)
@@ -49,7 +71,10 @@ signal_snr <- function(
     
     ## collect function arguments
     eseis_arguments <- list(data = "",
-                            detrend = detrend)
+                            scale = scale,
+                            detrend = detrend,
+                            envelope = envelope,
+                            method = method)
     
     ## check if input object is of class eseis
     if(class(data)[1] == "eseis") {
@@ -62,20 +87,56 @@ signal_snr <- function(
       
       ## extract signal vector
       data <- eseis_data$signal
+      
     } else {
       
       ## set eseis flag
       eseis_class <- FALSE
+      
     }
     
     ## optionally detrend data set
     if(detrend == TRUE) {
       
-      data <- signal_detrend(data = data)
+      data <- eseis::signal_detrend(data = data)
     }
     
-    ## calculate SNR
-    data_out <- abs(max(data, na.rm = TRUE) / mean(data, na.rm = TRUE))
+    ## optionally calculate envelope
+    if(envelope == TRUE) {
+      
+      data <- eseis::signal_envelope(data = data)
+    }
+    
+    ## check method keywords
+    if(method %in% c("max-mean", "mean-sd") == FALSE) {
+      
+      stop("Method keyword not supported!")
+      
+    } else if(method == "max-mean") {
+     
+      ## calculate SNR
+      data_out <- abs(max(data, na.rm = TRUE) / mean(data, na.rm = TRUE)) 
+      
+    } else if(method == "mean-sd") {
+      
+      ## calculate SNR
+      data_out <- abs(mean(data, na.rm = TRUE) / sd(data, na.rm = TRUE))
+    }
+    
+    ## optionally scale data set
+    if(scale %in% c("lin", "dB") == FALSE) {
+      
+      stop("Scale keyword not supported!")
+      
+    } else if(scale == "lin") {
+      
+      data_out <- data_out
+      
+    } else if(scale == "dB") {
+      
+      data_out <- 10 * log10(data_out)
+      
+    }
     
     ## optionally rebuild eseis object
     if(eseis_class == TRUE) {
